==> mapnik-3.0.12-4-aarch64.pkg.tar.xz: usr/include/mapnik/config_error.hpp <==
/*****************************************************************************
 *
 * This file is part of Mapnik (c++ mapping toolkit)
 *
 * Copyright (C) 2015 Artem Pavlenko
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *****************************************************************************/

#ifndef MAPNIK_CONFIG_ERROR_HPP
#define MAPNIK_CONFIG_ERROR_HPP

#include <mapnik/config.hpp>

#include <exception>
#include <string>

namespace mapnik {

class xml_node;

class config_error : public std::exception
{
public:
    config_error(std::string const& what);
    config_error(std::string const& what,
                 xml_node const& node);
    config_error(std::string const& what,
                 unsigned line_number,
                 std::string const& filename);
    virtual ~config_error() throw() {}

    virtual const char * what() const throw();

    void append_context(std::string const& ctx) const;
    void append_context(std::string const& ctx, xml_node const& node) const;
    void append_context(xml_node const& node) const;
protected:
    mutable std::string what_;
    mutable unsigned line_number_;
    mutable std::string file_;
    mutable std::string node_name_;
    mutable std::string msg_;
};

}

#endif // MAPNIK_CONFIG_ERROR_HPP

==> mapnik-4.1.1-1-aarch64.pkg.tar.xz: usr/include/mapnik/config_error.hpp <==
/*****************************************************************************
 *
 * This file is part of Mapnik (c++ mapping toolkit)
 *
 * Copyright (C) 2025 Artem Pavlenko
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *****************************************************************************/

#ifndef MAPNIK_CONFIG_ERROR_HPP
#define MAPNIK_CONFIG_ERROR_HPP

#include <mapnik/config.hpp>

#include <exception>
#include <string>

namespace mapnik {

class xml_node;

class config_error : public std::exception
{
  public:
    config_error(std::string const& what);
    config_error(std::string const& what, xml_node const& node);
    config_error(std::string const& what, unsigned line_number, std::string const& filename);
    virtual ~config_error() {}
    virtual const char* what() const noexcept;
    void append_context(std::string const& ctx) const;
    void append_context(std::string const& ctx, xml_node const& node) const;
    void append_context(xml_node const& node) const;

  protected:
    mutable std::string what_;
    mutable unsigned line_number_;
    mutable std::string file_;
    mutable std::string node_name_;
    mutable std::string msg_;
};

} // namespace mapnik

#endif // MAPNIK_CONFIG_ERROR_HPP
